pub struct AllowlistEntry {
pub channel: String,
pub peer_id: String,
pub label: Option<String>,
}Expand description
Allowlist entry.
Fields
channel: StringChannel pattern (“*” for any).
peer_id: StringPeer ID pattern (“*” for any).
label: Option<String>Optional label.
Implementations
Sourceimpl AllowlistEntry
impl AllowlistEntry
Sourcepub fn new(channel: impl Into<String>, peer_id: impl Into<String>) -> Self
pub fn new(channel: impl Into<String>, peer_id: impl Into<String>) -> Self
Create a new allowlist entry.
Sourcepub fn channel_wide(channel: impl Into<String>) -> Self
pub fn channel_wide(channel: impl Into<String>) -> Self
Create an entry that allows any peer on a channel.
Sourcepub fn peer_anywhere(peer_id: impl Into<String>) -> Self
pub fn peer_anywhere(peer_id: impl Into<String>) -> Self
Create an entry that allows a specific peer on any channel.